program main1
!----------------------------------------------------------------
!* authors:
!*
!* Alex Ignacio da Silva        ignacioalex@yahoo.com
!* and
!* Sueli M. Viegas              viegas@iagusp.usp.br
!*
!* Instituto Astronomico e Geofisico
!* Universidade de Sao Paulo
!* Av. Miguel Stefano, 4200
!* 04301-904 Sao Paulo - SP
!* Brazil
!*
!* This program is the testcase #1 of PopRatio.
!*
!* It calculates a diagnostic curve for the relative population
!* of the first excited level of atomic carbon 3P1/3P0 as a
!* function of neutral hydrogen volume density.
!* Several excitation mechanisms are taken into account.
!*
!*** Make sure the radiation field included in urad is Fgal. ***
!*
!* History:
!* Version    Date (D/M/Y)    Comment
!* -------    ------------    -------
!* 1.0        28/04/2000      original code (A.I. Silva)
!----------------------------------------------------------------

use Precision
use PopRatio

implicit none

!***************
!* parameters: *
!***************

integer, parameter :: npoints = 15 ! number of points to be calculated
real(WP), parameter :: lognHmin = -1.0_WP ! lower bound of H0 volume density, in cm^-3
real(WP), parameter :: lognHmax = 4.0_WP  ! upper bound of H0 volume density, in cm^-3

real(WP), parameter :: T = 100.0_WP ! kinetic temperature, in K
real(WP), parameter :: z = 1.0_WP ! redshift

!**************
!* variables: *
!**************

real(WP) :: nH ! H0 volume density
real(WP), dimension(6) :: n ! vector of collision partner densities

integer :: i ! counter

!**************
!* Main Body: *
!**************

open (1,file='CI.dat',status='old',action='read')
open (2,file='output1.dat',status='new',action='write')

! loads in a 3-level model atom
! (including all possible fluorescence transitions listed):
call InitPopRatio (1,3)

write (2,'(T3,"nH",T25,"n(3P1)/n(3P0)",T47,"n(3P2)/n(3P0)")')
do i=1, npoints
    nH = 10.0_WP ** (lognHmin + (i-1)*(lognHmax-lognHmin)/(npoints-1))
    n(1) = 1.E-4_WP * nH        ! electron density
    n(2) = 0.0_WP               ! proton density
    n(3) = nH                   ! H0 density
    n(4) = nH / 4.0_WP          ! para-H2 density
    n(5) = 3.0_WP / 4.0_WP * nH ! ortho-H2 density
    n(6) = nH / 10.0_WP         ! helium density
    call PopulationRatio (T,z,n)
    write (2,'(3ES22.14E2)') nH, X(1), X(2)
end do
! checks whether the LTE was reached at the end:
write (2,'("The largest deviation from LTE was:",ES22.14E2)') LTEdev(3,T)

call FinishPopRatio

close (2)
close (1)

end program main1
