program main2
!---------------------------------------------------------------
!* authors:
!*
!* Alex Ignacio da Silva        ignacioalex@yahoo.com
!* and
!* Sueli M. Viegas              viegas@iagusp.usp.br
!*
!* Instituto Astronomico e Geofisico
!* Universidade de Sao Paulo
!* Av. Miguel Stefano, 4200
!* 04301-904 Sao Paulo - SP
!* Brazil
!*
!* This program is the testcase #2 of PopRatio.
!*
!* It calculates the H0 volume density assuming the physical
!* conditions of testcase #1 and a given first excited level
!* population of C0, n(3P1)/n(3P0) .
!*
!*** Make sure the radiation field included in urad is Fgal. ***
!*
!* History:
!* Version    Date (D/M/Y)    Comment
!* -------    ------------    -------
!* 1.0        28/04/2000      original code (A.I. Silva)
!---------------------------------------------------------------

use Precision
use PopRatio

implicit none

!***************
!* parameters: *
!***************

integer, parameter :: itmax = 200 ! do not exceed this number of iterations

! precision at which nH is to be evaluated (delta(nH)/nH < epsilon):
real(WP), parameter :: epsilon = 1.0E-14_WP

real(WP), parameter :: T = 100.0_WP ! kinetic temperature, in K
real(WP), parameter :: z = 1.0_WP   ! redshift
real(WP), parameter :: pop = 0.2_WP ! n(3P1)/n(3P0)

!**************
!* variables: *
!**************

real(WP) :: nHmin = 1.0E-1_WP ! lower bound of H0 volume density, in cm^-3
real(WP) :: nHmax = 1.0E4_WP  ! upper bound of H0 volume density, in cm^-3
real(WP) :: nH ! H0 volume density
real(WP), dimension(6) :: n ! vector of collision partner densities

integer :: i = 0 ! counter
logical :: converged = .false. ! variable that signals when convergence is reached

!**************
!* Main Body: *
!**************

open (1,file='CI.dat',status='old',action='read')
open (2,file='output2.dat',status='new',action='write')

! loads in a 3-level model atom
! (including all possible fluorescence transitions listed):
call InitPopRatio (1,3)

do while ((.not. converged) .and. i<itmax)
    nH = (nHmax+nHmin)/2.0_WP
    n(1) = 1.E-4_WP * nH        ! electron density
    n(2) = 0.0_WP               ! proton density
    n(3) = nH                   ! H0 density
    n(4) = nH / 4.0_WP          ! para-H2 density
    n(5) = 3.0_WP / 4.0_WP * nH ! ortho-H2 density
    n(6) = nH / 10.0_WP         ! helium density
    call PopulationRatio (T,z,n)
    if ( X(1)>pop) then
        nHmax = nH
    else
        nHmin = nH
    end if
    if ( (nHmax-nHmin)/(nHmax+nHmin) <= epsilon ) converged=.true.
    i = i + 1
end do

if (converged) then
    nH = (nHmax+nHmin)/2.0_WP
    write (2,'(ES22.14E2)') nH
    write (2,'("Convergence reached after",I5," iterations.")') i
else
    write (2,'("Convergence not reached!")')
end if

call FinishPopRatio

close (2)
close (1)

end program main2
