program main3
!----------------------------------------------------------------
!* authors:
!*
!* Alex Ignacio da Silva        ignacioalex@yahoo.com
!* and
!* Sueli M. Viegas              viegas@iagusp.usp.br
!*
!* Instituto Astronomico e Geofisico
!* Universidade de Sao Paulo
!* Av. Miguel Stefano, 4200
!* 04301-904 Sao Paulo - SP
!* Brazil
!*
!* This program is the testcase #3 of PopRatio.
!*
!* It reads in the H0 volume density calculated in testcase #2
!* and calculates the rates for all the processes involved in
!* order to determine which ones are the most important.
!*
!*** Make sure the radiation field included in urad is Fgal. ***
!*
!* History:
!* Version    Date (D/M/Y)    Comment
!* -------    ------------    -------
!* 1.0        28/04/2000      original code (A.I. Silva)
!----------------------------------------------------------------

use Precision
use PopRatio

implicit none

!***************
!* parameters: *
!***************

real(WP), parameter :: T = 100.0_WP ! kinetic temperature, in K
real(WP), parameter :: z = 1.0_WP   ! redshift

!**************
!* variables: *
!**************

real(WP) :: nH ! H0 volume density
real(WP), dimension(6) :: n ! vector of collision partner densities

integer :: i ! counter

!**************
!* Main Body: *
!**************

open (1,file='CI.dat',status='old',action='read')
open (2,file='output2.dat',status='old',action='read')
open (3,file='output3.dat',status='new',action='write')

! loads in a 3-level model atom
! (including all possible fluorescence transitions listed):
call InitPopRatio (1,3)

read (2,'(ES22.14E2)') nH

n(1) = 1.E-4_WP * nH        ! electron density
n(2) = 0.0_WP               ! proton density
n(3) = nH                   ! H0 density
n(4) = nH / 4.0_WP          ! para-H2 density
n(5) = 3.0_WP / 4.0_WP * nH ! ortho-H2 density
n(6) = nH / 10.0_WP         ! helium density
call PopulationRatio (T,z,n)

write (3,*) "Excitation rates by the CMBR:"
write (3,'("3P0 -> 3P1 :",ES22.14E2," s^-1")') B(1,2)*u(1,2)
write (3,'("3P0 -> 3P2 :",ES22.14E2," s^-1")') B(1,3)*u(1,3)
write (3,*)

write (3,*) "Excitation rates by fluorescence:"
write (3,'("3P0 -> 3P1 :",ES22.14E2," s^-1")') gam(1,2)
write (3,'("3P0 -> 3P2 :",ES22.14E2," s^-1")') gam(1,3)
write (3,*)

write (3,*) "Excitation rates by collisions:"
do i=1, npartners
    write (3,*) CD(i)%partner_name
    write (3,'("3P0 -> 3P1 :",ES22.14E2," s^-1")') n(i)*CD(i)%q(1,2)
    write (3,'("3P0 -> 3P2 :",ES22.14E2," s^-1")') n(i)*CD(i)%q(1,3)
end do

call FinishPopRatio

close (3)
close (2)
close (1)

end program main3
