program main4
!-----------------------------------------------------------------
!* authors:
!*
!* Alex Ignacio da Silva        ignacioalex@yahoo.com
!* and
!* Sueli M. Viegas              viegas@iagusp.usp.br
!*
!* Instituto Astronomico e Geofisico
!* Universidade de Sao Paulo
!* Av. Miguel Stefano, 4200
!* 04301-904 Sao Paulo - SP
!* Brazil
!*
!* This program is the testcase #4 of PopRatio.
!*
!* It calculates emissivity ratios of intercombination 4P->2P
!* lines of C+ as a function of electron density.
!*
!*** Make sure the radiation field included in urad is a black body of T=4000K : ***
!***                 urad = Planck(4.0E3_WP,c/lambda*1.0E8_WP)                   ***
!*
!* History:
!* Version    Date (D/M/Y)    Comment
!* -------    ------------    -------
!* 1.0        28/04/2000      original code (A.I. Silva)
!-----------------------------------------------------------------

use Precision
use PopRatio

implicit none

!***************
!* parameters: *
!***************

integer, parameter :: npoints = 15 ! number of points to be calculated
real(WP), parameter :: lognemin = 5.0_WP  ! lower bound of electron volume density, in cm^-3
real(WP), parameter :: lognemax = 12.0_WP ! upper bound of electron volume density, in cm^-3

real(WP), parameter :: T = 1.0E4_WP ! kinetic temperature, in K

!**************
!* variables: *
!**************

real(WP), dimension(5) :: n ! vector containing the densities of collision partners
real(WP) :: R1 ! (4P5/2->2P3/2) / (4P1/2->2P3/2)
real(WP) :: R2 ! (4P5/2->2P3/2) / (4P3/2->2P3/2)
real(WP) :: R3 ! (4P1/2->2P1/2) / (4P3/2->2P3/2)

integer :: i ! counter

!**************
!* Main Body: *
!**************

open (1,file='CII.dat',status='old',action='read')
open (2,file='output4.dat',status='new',action='write')

! loads in a 5-level model ion
! (including all possible fluorescence transitions listed):
call InitPopRatio (1,5)

write (2,'(T3,"ne [cm^-3]",T25,"R1",T47,"R2",T69,"R3")')
n = 0.0_WP
do i=1, npoints
    n(1) = 10.0_WP ** ( lognemin + (i-1)*(lognemax-lognemin)/(npoints-1) ) ! ne
    n(2) = n(1) ! proton density

    ! calculates the population ratios taking into account the effect of collisions
    ! by electrons and protons and a black body of T=4000K and a geometrical dilution
    ! factor f=0.5 : 
    call PopulationRatio (T,-1.0_WP,n,f=0.5_WP)

    ! calculates the emissivity ratios:
    R1 = (X(4)*A(5,2)*(E(5)-E(2))) / (X(2)*A(3,2)*(E(3)-E(2)))
    R2 = (X(4)*A(5,2)*(E(5)-E(2))) / (X(3)*A(4,2)*(E(4)-E(2)))
    R3 = (X(2)*A(3,1)*(E(3)-E(1))) / (X(3)*A(4,2)*(E(4)-E(2)))

    write (2,'(4ES22.14E2)') n(1), R1, R2, R3 
end do

! checks whether the LTE was reached at the end:
write (2,'("The largest deviation from LTE was:",ES22.14E2)') LTEdev(5,T)

call FinishPopRatio

close (2)
close (1)

end program main4
