program main5
!-----------------------------------------------------------------
!* authors:
!*
!* Alex Ignacio da Silva        ignacioalex@yahoo.com
!* and
!* Sueli M. Viegas              viegas@iagusp.usp.br
!*
!* Instituto Astronomico e Geofisico
!* Universidade de Sao Paulo
!* Av. Miguel Stefano, 4200
!* 04301-904 Sao Paulo - SP
!* Brazil
!*
!* This program is the testcase #5 of PopRatio.
!*
!* It evaluates the cooling function of Fe II at a given kinetic
!* temperature as a function of the volume density of electrons.
!*
!* History:
!* Version    Date (D/M/Y)    Comment
!* -------    ------------    -------
!* 1.0        28/04/2000      original code (A.I. Silva)
!-----------------------------------------------------------------

use Precision
use PhysMath
use PopRatio

implicit none

!***************
!* parameters: *
!***************

integer, parameter :: imax = 16

integer, parameter :: npoints = 15 ! number of points to be calculated
real(WP), parameter :: lognemin = -2.0_WP ! lower bound of electron volume density, in cm^-3
real(WP), parameter :: lognemax = 4.0_WP  ! upper bound of electron volume density, in cm^-3

real(WP), parameter :: T = 1.0E4_WP ! kinetic temperature, in K

!**************
!* variables: *
!**************

real(WP), dimension(1) :: n ! vector containing the density of electrons
real(WP) :: CoolingFunction

integer :: i, j, l ! counters

!**************
!* Main Body: *
!**************

open (1,file='FeII.dat',status='old',action='read')
open (2,file='output5.dat',status='new',action='write')

! loads in a 16-level model atom (no fluorescence transitions):
call InitPopRatio (1,16,0.0_WP,0.0_WP)

write (2,'("electron dens. [cm^-3]",T25,"cooling function [erg/s/cm^3/cm^3]")')
do i=1, npoints
    n(1) = 10.0_WP ** ( lognemin + (i-1)*(lognemax-lognemin)/(npoints-1) )
    call PopulationRatio (T,-1.0_WP,n,f=0.0_WP)

    ! calculates the cooling function:
    CoolingFunction = 0.0_WP
    do j=2, imax
        do l=1, j-1
            CoolingFunction = CoolingFunction + X(j-1)*A(j,l)*(E(j)-E(l))*h*c ! E in cm^-1
        end do
    end do
    CoolingFunction = CoolingFunction / ( 1 + sum(X) )

    write (2,'(2ES22.14E2)') n(1), CoolingFunction 
end do

call FinishPopRatio

close (2)
close (1)

end program main5
